@@ -5,7 +5,7 @@ package App::Pastebin::Create;
 # FILE HOLDER/THIS IS COMMAND LINE APP, executable name is pastebin-create
 # The executable located in bin/
 # type pastebin -h for usage
-our $VERSION = '1.0101'; # VERSION
+our $VERSION = '1.0102'; # VERSION
 
 __END__
 
@@ -19,7 +19,7 @@ App::Pastebin::Create - Simple CLI App to create and upload to Pastebin.com
 
 =head1 VERSION
 
-version 1.0101
+version 1.0102
 
 =head1 SYNOPSIS
 
@@ -65,7 +65,7 @@ Your paste title description.
 
 =head1 Testing & Manual Installation
 
-	perl Makefile.pl && make test
+	perl Makefile.PL && make test
 	
 	# install
 	make install
